leaftools.change_written_leaf_duration_and_preserve_preprolated_leaf_duration
=============================================================================

.. autofunction:: abjad.tools.leaftools.change_written_leaf_duration_and_preserve_preprolated_leaf_duration.change_written_leaf_duration_and_preserve_preprolated_leaf_duration
